@@ -1,4 +1,6 @@
 #include <fftw3.h>
+#define STRICT_R_HEADERS
+#include <float.h>
 #include <Rcpp.h>
 
 using namespace std;
